Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(311)

Unified Diff: tests/compiler/dart2js/deferred_load_graph_segmentation_test.dart

Issue 873543004: Native classes are now part of the classes-list. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Just adapt the test instead of removing it. Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/compiler/dart2js/deferred_load_graph_segmentation_test.dart
diff --git a/tests/compiler/dart2js/deferred_load_graph_segmentation_test.dart b/tests/compiler/dart2js/deferred_load_graph_segmentation_test.dart
index a3ead0b2a6aee191dddcfc4859fc6497a70fea3f..1927db086c96fcd024becd3353bdaf63766f19b4 100644
--- a/tests/compiler/dart2js/deferred_load_graph_segmentation_test.dart
+++ b/tests/compiler/dart2js/deferred_load_graph_segmentation_test.dart
@@ -76,9 +76,8 @@ void main() {
Expect.notEquals(ou_lib1, ou_lib2);
Expect.notEquals(ou_lib4_1, ou_lib4_2);
Expect.notEquals(ou_lib1, ou_lib4_2);
- // InputElement is native, so it should not appear on a classList
- Expect.isFalse(outputClassLists[outputUnitForElement(inputElement)]
- .contains(inputElement));
+ // InputElement is native, so it should be in the mainOutputUnit.
+ Expect.equals(mainOutputUnit, outputUnitForElement(inputElement));
var hunksToLoad = compiler.deferredLoadTask.hunksToLoad;
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698